==> flowblade_1.4.orig.tar.gz: flowblade-1.4/README.md <==

![Flowblade](flowblade-trunk/Flowblade/res/img/header_text.png "Flowblade")

**Release 1.4 is now avalable. See [release notes](./flowblade-trunk/docs/RELEASE_NOTES.md) for more info.**

**Contents:**
  1. [Introduction](https://github.com/jliljebl/flowblade#introduction)
  1. [Features](https://github.com/jliljebl/flowblade#features)
  1. [Releases](https://github.com/jliljebl/flowblade#releases)
  1. [Installing Flowblade](https://github.com/jliljebl/flowblade#installing-flowblade)
  1. [Docs](https://github.com/jliljebl/flowblade#docs)
  1. [Screenshot](https://github.com/jliljebl/flowblade#screenshot)
  1. [Forum and Contact](https://github.com/jliljebl/flowblade#forum-and-contact)

# Introduction

Flowblade Movie Editor is a **multitrack non-linear video editor** for Linux released under **GPL 3 license**.

Flowblade is designed to provide a fast, precise and robust editing experience. Flowblade employs a film-style insert editing model as workflow. In insert editing clips are generally placed tightly after other clips when they are inserted on the timeline. Edits are fine tuned by trimming in and out points of clips or by cutting and deleting parts of clips.

Flowblade provides powerful tools to mix and filter video and audio.

# Features

**Editing:**

  * 3 move tools
  * 3 trim tools
  * 4 methods to insert / overwrite / append clips on the timeline
  * Drag'n'Drop clips on the timeline
  * Clip and compositor parenting with other clips
  * Max. 9 combined video and audio tracks available

**Image compositing:**

  * 6 compositors. Mix, zoom, move and rotate source video with keyframed animation tools
  * 19 blends. Stardand image blend modes like Add, Hardlight and Overlay are available
  * 40+ pattern wipes. 

**Image and audio filtering:**

  * 50+ image filters: color correction, image effects, distorts, alpha manipulation, blur, edge detection, motion effects, freeze frame, etc.
  * 30+ audio filters: keyframed volume mixing, echo, reverb, distort, etc.

**Supported editable media types:**

  * Most common video and audio formats, depends on installed MLT/FFMPEG codecs
  * JPEG, PNG, TGA, TIFF graphics file types
  * SVG vector graphics
  * Numbered frame sequences 

**Output encoding:**

  * Most common video and audio formats, depends on installed MLT/FFMPEG codecs
  * User can define rendering by setting FFMpeg args individually
        
# Releases

**Latest release:** Flowblade Movie Editor 1.4 was released on November 24, 2015.

**Next release:** Flowblade Movie Editor 1.6 will be out on March 2016.

# Installing Flowblade

Installing instructions are available [here](./flowblade-trunk/docs/INSTALLING.md).

# Docs

[FAQ](./flowblade-trunk/docs/FAQ.md)

[Roadmap](./flowblade-trunk/docs/ROADMAP.md)

[Release notes](./flowblade-trunk/docs/RELEASE_NOTES.md)

[Creating a translation](./flowblade-trunk/docs/CREATING_TRANSLATION.md)

[Dependencies](./flowblade-trunk/docs/DEPENDENCIES.md)



# Screenshot

[Screenshot](./flowblade-trunk/docs/Screenshot-0-18.png) for version is 0.18 is available in the */docs* folder.

# Forum and Contact

For questions and discussion on Flowblade we have a [Google+ group] (https://plus.google.com/u/0/communities/103860400113389238474) available. There will be some updates on what is happening with the project too.

Use the **Issues** tab on the right to give bug reports or to make feature requests.

If needed, contact the project lead for additional information: janne.liljeblad@gmail.com

==> flowblade_1.16.orig.tar.gz: flowblade-1.16/README.md <==

![Flowblade](flowblade-trunk/Flowblade/res/img/header_text.png "Flowblade")

**Updating to MLT 6.6.0 from 6.5.0 version fixes startup crashes, [more info](./flowblade-trunk/docs/SDL_2_AND_MLT_6_6_0.md).**

**Contents:**
  1. [Introduction](https://github.com/jliljebl/flowblade#introduction)
  1. [Features](https://github.com/jliljebl/flowblade#features)
  1. [Releases](https://github.com/jliljebl/flowblade#releases)
  1. [Installing Flowblade](https://github.com/jliljebl/flowblade#installing-flowblade)
  1. [Docs](https://github.com/jliljebl/flowblade#docs)
  1. [Screenshot](https://github.com/jliljebl/flowblade#screenshot)
  1. [Forum, Webpage and Contact](https://github.com/jliljebl/flowblade#forum-webpage-and-contact)

# Introduction

Flowblade is a **multitrack non-linear video editor** for Linux released under **GPL 3 license**.

Flowblade is designed to provide a fast, precise and robust editing experience. Flowblade employs a film-style insert editing model as workflow. In insert editing clips are generally placed tightly after other clips when they are inserted on the timeline. Edits are fine tuned by trimming in and out points of clips or by cutting and deleting parts of clips.

Flowblade provides powerful tools to mix and filter video and audio.

# Features

**Editing:**

  * 4 move tools
  * 3 trim tools
  * 4 methods to insert / overwrite / append clips on the timeline
  * Drag'n'Drop clips on the timeline
  * Clip and compositor parenting with other clips
  * Max. 9 combined video and audio tracks available

**Image compositing:**

  * 6 compositors. Mix, zoom, move and rotate source video with keyframed animation tools
  * 19 blends. Stardand image blend modes like Add, Hardlight and Overlay are available
  * 40+ pattern wipes. 

**Image and audio filtering:**

  * 50+ image filters: color correction, image effects, distorts, alpha manipulation, blur, edge detection, motion effects, freeze frame, etc.
  * 30+ audio filters: keyframed volume mixing, echo, reverb, distort, etc.

**Supported editable media types:**

  * Most common video and audio formats, depends on installed MLT/FFMPEG codecs
  * JPEG, PNG, TGA, TIFF graphics file types
  * SVG vector graphics
  * Numbered frame sequences 

**Output encoding:**

  * Most common video and audio formats, depends on installed MLT/FFMPEG codecs
  * User can define rendering by setting FFMpeg args individually
        
# Releases

**Latest release:** Flowblade Movie Editor 1.14 was released on October 2017.

**Next release:** Flowblade Movie Editor 1.16 will be out on March 2018.

# Installing Flowblade

Installing instructions are available [here](./flowblade-trunk/docs/INSTALLING.md).

# Docs

[FAQ](./flowblade-trunk/docs/FAQ.md)

[Known Issues](./flowblade-trunk/docs/KNOWN_ISSUES.md)

[Roadmap](./flowblade-trunk/docs/ROADMAP.md)

[Release notes](./flowblade-trunk/docs/RELEASE_NOTES.md)

[Creating a translation](./flowblade-trunk/docs/CREATING_TRANSLATION.md)

[Dependencies](./flowblade-trunk/docs/DEPENDENCIES.md)



# Screenshot

[Screenshot 1.4 dark theme](./flowblade-trunk/docs/Screenshot-1-4-dark.png)

[Screenshot 0.18 light theme](./flowblade-trunk/docs/Screenshot-0-18.png)

These are in the repository */docs* folder.


# Forum, Webpage and Contact

[The project webpage is here](http://jliljebl.github.io/flowblade/). 

For questions and discussion on Flowblade we have a [Google+ group](https://plus.google.com/u/0/communities/103860400113389238474) available. There will be some updates on what is happening with the project too.

Use the **Issues** tab to give bug reports or to make feature requests.

If needed, contact the project lead for additional information: janne.liljeblad@gmail.com
